@import url("http://fonts.googleapis.com/css?family=Open+Sans|Cousine|Michroma");

body {
	font-family:'Open Sans',sans-serif;
	font-size:86%;
	background: #f8f8f8;
	color: #101010;
}

pre {
	font-family:'Cousine',sans-serif;
}

tt {
	font-family:'Cousine',sans-serif;
	font-size: 90%;
	background-color: #e0e0e0;
	padding: 0.2em;
}

h1.title {
	margin-top:0em;
	font-family:'Michroma',sans-serif;
	font-size:250%;
}

h1 {
	margin-top:1.5em;
	font-size:160%;
	//text-shadow: #808080 1px 1px 1px;
}

h2 {
	font-size:115%;
}

h3 {
	font-size:105%;
}

h1, h2, h3 {
	color: #2050a0;
}

summary {
	color: #2050a0;
}

details {
	padding-left: 1.8em;
}

.left {
	padding-left: 0em;
}

a:link {
	color: #2050a0;
}

a:visited {
	color: #808080;
}

body {
	margin-left: 3em;
	margin-right: 3em;
	margin-top: 1em;
	margin-bottom: 2em;
	padding: 0;
}

ul {
	list-style-type: square;
	color: #404040;
}
/*
table {
	margin-left: 2.5em;
	margin-right: 2.5em;
	border-collapse: collapse;
}

td {
	border-width: 1px;
	padding: 0.1em;
	border-style: solid;
	border-color: #a0a0a0;
}

thead {
	font-weight: bold;
	background: #c0d0ff;
}
*/
.literal-block {
	background-color: #e0e0e0;
}

.term {
	color: #c0c0c0;
	background-color: #000000;
	margin-left: 6em;
	margin-right: 6em;
	margin-bottom: 2em;
	padding: 1em;
	border-radius: 0.6em;
	-moz-border-radius: 0.6em;
}
